==> glpi-0.80.2.tar.gz: glpi/install/update_080_0801.php <==
<?php

/*
 * @version $Id: update_080_0801.php 14783 2011-06-28 09:35:58Z moyo $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2011 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 --------------------------------------------------------------------------
 */

// ----------------------------------------------------------------------
// Original Author of file:
// Purpose of file:
// ----------------------------------------------------------------------

/**
 * Update from 0.802 to 0.80.1
 *
 * @param $output string for format
 *       HTML (default) for standard upgrade
 *       empty = no ouput for PHPUnit
 *
 * @return bool for success (will die for most error)
**/
function update080to0801($output='HTML') {
   global $DB, $LANG, $migration;

   $updateresult     = true;
   $ADDTODISPLAYPREF = array();

   if ($output) {
      echo "<h3>".$LANG['install'][4]." -&gt; 0.80.1</h3>";
   }

   // Clean duplicates
   $query = "SELECT COUNT(*) AS CPT, `tickets_id`, `type`, `groups_id`
               FROM `glpi_groups_tickets`
               GROUP BY `tickets_id`, `type`, `groups_id`
               HAVING CPT > 1";
   if ($result=$DB->query($query)) {
      if ($DB->numrows($result)>0) {
         while ($data=$DB->fetch_array($result)) {
            // Skip first
            $query = "SELECT `id`
                        FROM `glpi_groups_tickets`
                        WHERE `tickets_id` = '".$data['tickets_id']."'
                           AND `type` = '".$data['type']."'
                           AND `groups_id` = '".$data['groups_id']."'
                        ORDER BY `id` DESC
                        LIMIT 1,99999";
            if ($result2=$DB->query($query)) {
               if ($DB->numrows($result2)) {
                  while ($data2=$DB->fetch_array($result2)) {
                     $query = "DELETE
                                 FROM `glpi_groups_tickets`
                                 WHERE `id` ='".$data2['id']."'";
                     $DB->query($query)
                     or die("0.80.1 clean to update glpi_groups_tickets ".
                              $LANG['update'][90] . $DB->error());
                  }
               }
            }
         }
      }
   }
   $migration->dropKey('glpi_groups_tickets', 'unicity');
   $migration->migrationOneTable('glpi_groups_tickets');
   $migration->addKey("glpi_groups_tickets", array('tickets_id', 'type','groups_id'),
                        "unicity", "UNIQUE");

   // Clean duplicates
   $query = "SELECT COUNT(*) AS CPT, `tickets_id`, `type`, `users_id`, `alternative_email`
               FROM `glpi_tickets_users`
               GROUP BY `tickets_id`, `type`, `users_id`, `alternative_email`
               HAVING CPT > 1";
   if ($result=$DB->query($query)) {
      if ($DB->numrows($result)>0) {
         while ($data=$DB->fetch_array($result)) {
            // Skip first
            $query = "SELECT `id`
                        FROM `glpi_tickets_users`
                        WHERE `tickets_id` = '".$data['tickets_id']."'
                           AND `type` = '".$data['type']."'
                           AND `users_id` = '".$data['users_id']."'
                           AND `alternative_email` = '".$data['alternative_email']."'
                        ORDER BY `id` DESC
                        LIMIT 1,99999";
            if ($result2=$DB->query($query)) {
               if ($DB->numrows($result2)) {
                  while ($data2=$DB->fetch_array($result2)) {
                     $query = "DELETE
                                 FROM `glpi_tickets_users`
                                 WHERE `id` ='".$data2['id']."'";
                     $DB->query($query)
                     or die("0.80.1 clean to update glpi_tickets_users ".
                              $LANG['update'][90] . $DB->error());
                  }
               }
            }
         }
      }
   }
   $migration->dropKey('glpi_tickets_users', 'tickets_id');
   $migration->migrationOneTable('glpi_tickets_users');
   $migration->addKey("glpi_tickets_users",
                     array('tickets_id', 'type','users_id','alternative_email'),
                     "unicity", "UNIQUE");

   $migration->addField("glpi_ocsservers", "ocs_version", "VARCHAR( 255 ) NULL");

   if ($migration->addField("glpi_slalevels", "entities_id", "INT( 11 ) NOT NULL DEFAULT 0")) {
      $migration->addField("glpi_slalevels", "is_recursive", "TINYINT( 1 ) NOT NULL DEFAULT 0");
      $migration->migrationOneTable('glpi_slalevels');

      $entities    = getAllDatasFromTable('glpi_entities');
      $entities[0] = "Root";


      foreach ($entities as $entID => $val) {
         // Non recursive ones
         $query3 = "UPDATE `glpi_slalevels`
                    SET `entities_id` = $entID, `is_recursive` = 0
                    WHERE `slas_id` IN (SELECT `id`
                                        FROM `glpi_slas`
                                        WHERE `entities_id` = $entID
                                              AND `is_recursive` = 0)";
         $DB->query($query3)
         or die("0.80.1 update entities_id and is_recursive=0 in glpi_slalevels ".$LANG['update'][90].
                $DB->error());

         // Recursive ones
         $query3 = "UPDATE `glpi_slalevels`
                    SET `entities_id` = $entID, `is_recursive` = 1
                    WHERE `slas_id` IN (SELECT `id`
                                        FROM `glpi_slas`
                                        WHERE `entities_id` = $entID
                                              AND `is_recursive` = 1)";
         $DB->query($query3)
         or die("0.80.1 update entities_id and is_recursive=1 in glpi_slalevels ".$LANG['update'][90].
                $DB->error());
      }
   }


   // must always be at the end
   $migration->executeMigration();

   return $updateresult;
}
?>

==> glpi-0.80.61.tar.gz: glpi/install/update_071_0712.php <==
<?php


/*
 * @version $Id: update_071_0712.php 14684 2011-06-11 06:32:40Z remi $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2011 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 --------------------------------------------------------------------------
 */

// ----------------------------------------------------------------------
// Original Author of file:
// Purpose of file:
// ----------------------------------------------------------------------

/// Update from 0.71 to 0.71.2
function update071to0712() {
	global $DB, $CFG_GLPI, $LANG;


	$query="UPDATE glpi_display SET num=120 WHERE num=121"	;
	$DB->query($query) or die("0.71.2 Update display index in view item ".$LANG['update'][90].$DB->error());

	$query="UPDATE glpi_rules_actions SET field='_ignore_ocs_import' WHERE action_type='ignore'"	;
	$DB->query($query) or die("0.71.2 Update ignore field for soft dict ".$LANG['update'][90].$DB->error());

} // fin 0.71 #####################################################################################
?>
